The function extracts the mode (profile or centroided) from the
raw mass spectrometry file by parsing the mzML file directly. If
the object x stems from any other type of file, NAs are
returned.
Arguments
- x
An object of class OnDiskMSnExp.
Details
This function is much faster than isCentroided(), which
estimates mode from the data, but is limited to data stemming from
mzML files which are still available in their original location
(and accessed with fileNames(x)).
Examples
f <- MsDataHub::TMT_Erwinia_1uLSike_Top10HCD_isol2_45stepped_60min_01.20141210.mzML.gz()
#> see ?MsDataHub and browseVignettes('MsDataHub') for documentation
#> loading from cache
x <- readMSData(f, mode = "onDisk")
table(isCentroidedFromFile(x), msLevel(x))
#> < table of extent 0 x 2 >